@@ -1,8 +1,16 @@
-#!@path_perl@
-eval 'exec @path_perl@ -S $0 ${1+"$@"}'
+#!@PATH_PERL@
+eval 'exec @PATH_PERL@ -S $0 ${1+"$@"}'
     if $running_under_some_shell;
+
 require 5.003;
-require "slice_boot.pl";
+
+BEGIN { $^W = 0; } # get rid of nasty warnings
+
+#   bootstrapping private installed modules
+use lib "@INSTALLPRIVLIB@";
+use lib "@INSTALLARCHLIB@";
+use lib "@INSTALLSITELIB@";
+use lib "@INSTALLSITEARCH@";
 
 ##         _ _          
 ##     ___| (_) ___ ___ 
