@@ -44,6 +44,15 @@ sub pass2 {
     $set  = new Bit::Vector($n); # working set
     $setA = new Bit::Vector($n); # "all" set
 
+    #   restore slice names
+    foreach $slice (keys(%{$CFG->{SLICE}->{SET}->{ASC}})) {
+        $asc = $CFG->{SLICE}->{SET}->{ASC}->{$slice};
+        delete $CFG->{SLICE}->{SET}->{ASC}->{$slice};
+        $slice =~ s|:\d+$||g;
+        $CFG->{SLICE}->{SET}->{ASC}->{$slice} .=
+                 ($CFG->{SLICE}->{SET}->{ASC}->{"$slice"} ? ',' : '') . $asc;
+    }
+
     #   convert ASCII representation to real internal set objects
     foreach $slice (keys(%{$CFG->{SLICE}->{SET}->{ASC}})) {
         $asc = $CFG->{SLICE}->{SET}->{ASC}->{$slice};
