@@ -28,5 +28,12 @@ sub error {
     exit(1);
 }
 
+sub printwarning {
+    my ($str) = @_;
+
+    $str =~ s|^|** Slice:Warning: |mg;
+    print STDERR $str;
+}
+
 1;
 ##EOF##
